<?php
/**
 * Service Post Type
 *
 * Register post types and taxonomies.
 */
class Service_Post_Type_Registrations {

	public $post_type = 'emd_service';
	public $taxonomies = array( 'emd_service_category' );

	public function init() {
		// Add the "service" post type and taxonomies
		add_action( 'init', array( $this, 'register' ) );
	}

	public function register() {
		$this->register_post_type();
		$this->register_taxonomy_category();
	}

	/**
	 * Register the custom post type.
	 */
	protected function register_post_type() {
		$theme_slug = get_option( 'stylesheet' );
		if ( strpos( $theme_slug, '-child' ) !== false ) {
			$theme_slug = substr( $theme_slug, 0, strpos( $theme_slug, '-child' ) );
		}
		
		global ${ $theme_slug . "_options" }, ${ $theme_slug . "_config" };
		$theme_options = ${ $theme_slug . "_options" };
		$service_cpt_i18n = ${ $theme_slug . "_config" }['service-cpt-i18n'];
		
		$service_slug = ! empty( $theme_options['service-slug'] ) ? $theme_options['service-slug'] : 'service';
		
		$labels = ! empty( $service_cpt_i18n['labels'] ) ? $service_cpt_i18n['labels'] : array(
			'name'               => __( 'Services', 'benchmark-cpts' ),
			'singular_name'      => __( 'Service', 'benchmark-cpts' ),
			'menu_name'          => __( 'Services', 'benchmark-cpts' ),
			'name_admin_bar'     => __( 'Service', 'benchmark-cpts' ),
			'all_items'          => __( 'All Items', 'benchmark-cpts' ),
			'add_new'            => __( 'Add New Item', 'benchmark-cpts' ),
			'add_new_item'       => __( 'Add New Service', 'benchmark-cpts' ),
			'edit_item'          => __( 'Edit Service', 'benchmark-cpts' ),
			'new_item'           => __( 'New Service', 'benchmark-cpts' ),
			'view_item'          => __( 'View Item', 'benchmark-cpts' ),
			'search_items'       => __( 'Search Items', 'benchmark-cpts' ),
			'not_found'          => __( 'No services found', 'benchmark-cpts' ),
			'not_found_in_trash' => __( 'No services found in trash', 'benchmark-cpts' ),
		);

		$supports = array(
			'title',
			'editor',
			'excerpt',
			'thumbnail',
			//'revisions',
			'page-attributes',
		);

		$args = array(
			'labels'            => $labels,
			'supports'          => $supports,
			'public'            => true,
			'show_in_nav_menus' => true,
			'capability_type'   => 'post',
			'rewrite'           => array( 'slug' => $service_slug ), // Permalinks format
			'menu_position'     => 110,
			'menu_icon'         => 'dashicons-hammer',
			'has_archive'       => false,
		);

		$args = apply_filters( 'emd_service_post_type_args', $args );

		register_post_type( $this->post_type, $args );
	}

	/**
	 * Register a taxonomy for Service Categories.
	 */
	protected function register_taxonomy_category() {
		$theme_slug = get_option( 'stylesheet' );
		if ( strpos( $theme_slug, '-child' ) !== false ) {
			$theme_slug = substr( $theme_slug, 0, strpos( $theme_slug, '-child' ) );
		}
		
		global ${ $theme_slug . "_options" }, ${ $theme_slug . "_config" };
		$theme_options = ${ $theme_slug . "_options" };
		$service_cpt_i18n = ${ $theme_slug . "_config" }['service-cpt-i18n'];
		
		$service_category_slug = ! empty( $theme_options['service-category-slug'] ) ? $theme_options['service-category-slug'] : 'service-category';
		
		$labels = ! empty( $service_cpt_i18n['cat-labels'] ) ? $service_cpt_i18n['cat-labels'] : array(
			'name'          => __( 'Service Categories', 'benchmark-cpts' ),
			'singular_name' => __( 'Service Category', 'benchmark-cpts' ),
			'menu_name'     => __( 'Categories', 'benchmark-cpts' ),
			'all_items'     => __( 'All Categories', 'benchmark-cpts' ),
			'edit_item'     => __( 'Edit Service Category', 'benchmark-cpts' ),
			'view_item'     => __( 'View Service Category', 'benchmark-cpts' ),
			'update_item'   => __( 'Update Service Category', 'benchmark-cpts' ),
			'add_new_item'  => __( 'Add New Category', 'benchmark-cpts' ),
			'new_item_name' => __( 'New Category Name', 'benchmark-cpts' ),
			'parent_item'   => __( 'Parent Service Category', 'benchmark-cpts' ),
			'search_items'  => __( 'Search Categories', 'benchmark-cpts' ),
		);

		$args = array(
			'labels'            => $labels,
			'public'            => true,
			'show_in_nav_menus' => true,
			'show_tagcloud'     => true,
			'hierarchical'      => true,
			'rewrite'           => array( 'slug' => $service_category_slug ),
			'show_admin_column' => true,
			'query_var'         => true,
		);

		$args = apply_filters( 'emd_service_post_type_category_args', $args );

		register_taxonomy( $this->taxonomies[0], $this->post_type, $args );
	}
}
