<?php
/**
 * Slide Post Type
 *
 * Register post types and taxonomies.
 */
class Slide_Post_Type_Registrations {

	public $post_type = 'emd_slide';
	public $taxonomies = array( 'emd_slide_group' );

	public function init() {
		// Add the "slide" post type and taxonomies
		add_action( 'init', array( $this, 'register' ) );
	}

	public function register() {
		$this->register_post_type();
		$this->register_taxonomy_category();
	}

	/**
	 * Register the custom post type.
	 */
	protected function register_post_type() {
		$theme_slug = get_option( 'stylesheet' );
		if ( strpos( $theme_slug, '-child' ) !== false ) {
			$theme_slug = substr( $theme_slug, 0, strpos( $theme_slug, '-child' ) );
		}
		
		global ${ $theme_slug . "_config" };
		$slide_cpt_i18n = ${ $theme_slug . "_config" }['slide-cpt-i18n'];

		$labels = ! empty( $slide_cpt_i18n['labels'] ) ? $slide_cpt_i18n['labels'] : array(
			'name'               => __( 'Slides', 'benchmark-cpts' ),
			'singular_name'      => __( 'Slide', 'benchmark-cpts' ),
			'menu_name'          => __( 'Home Slider', 'benchmark-cpts' ),
			'name_admin_bar'     => __( 'Slide', 'benchmark-cpts' ),
			'all_items'          => __( 'All Slides', 'benchmark-cpts' ),
			'add_new'            => __( 'Add New Slide', 'benchmark-cpts' ),
			'add_new_item'       => __( 'Add New Slide', 'benchmark-cpts' ),
			'edit_item'          => __( 'Edit Slide', 'benchmark-cpts' ),
			'new_item'           => __( 'New Slide', 'benchmark-cpts' ),
			'view_item'          => __( 'View Slide', 'benchmark-cpts' ),
			'search_items'       => __( 'Search Slides', 'benchmark-cpts' ),
			'not_found'          => __( 'No slides found', 'benchmark-cpts' ),
			'not_found_in_trash' => __( 'No slides found in trash', 'benchmark-cpts' ),
		);

		$supports = array(
			'title',
			'editor',
			'thumbnail',
			'page-attributes',
		);

		$args = array(
			'labels'              => $labels,
			'supports'            => $supports,
			'public'              => false,
			'exclude_from_search' => true,
			'show_ui'             => true,
			'capability_type'     => 'post',
			'hierarchical'        => false,
			'rewrite'             => false,
			'menu_position'       => 105,
			'menu_icon'           => 'dashicons-format-gallery',
			'has_archive'         => false,
			'query_var'           => false,
		);

		$args = apply_filters( 'emd_slide_post_type_args', $args );

		register_post_type( $this->post_type, $args );
	}

	/**
	 * Register a taxonomy for Slide Categories.
	 */
	protected function register_taxonomy_category() {
		$theme_slug = get_option( 'stylesheet' );
		if ( strpos( $theme_slug, '-child' ) !== false ) {
			$theme_slug = substr( $theme_slug, 0, strpos( $theme_slug, '-child' ) );
		}
		
		global ${ $theme_slug . "_config" };
		$slide_cpt_i18n = ${ $theme_slug . "_config" }['slide-cpt-i18n'];

		$labels = ! empty( $slide_cpt_i18n['cat-labels'] ) ? $slide_cpt_i18n['cat-labels'] : array(
			'name'          => __( 'Slide Groups', 'benchmark-cpts' ),
			'singular_name' => __( 'Slide Group', 'benchmark-cpts' ),
			'menu_name'     => __( 'Slide Groups', 'benchmark-cpts' ),
			'all_items'     => __( 'All Groups', 'benchmark-cpts' ),
			'edit_item'     => __( 'Edit Slide Group', 'benchmark-cpts' ),
			'view_item'     => __( 'View Slide Group', 'benchmark-cpts' ),
			'update_item'   => __( 'Update Slide Group', 'benchmark-cpts' ),
			'add_new_item'  => __( 'Add New Group', 'benchmark-cpts' ),
			'new_item_name' => __( 'New Group Name', 'benchmark-cpts' ),
			'parent_item'   => __( 'Parent Group', 'benchmark-cpts' ),
			'search_items'  => __( 'Search Groups', 'benchmark-cpts' ),
		);

		$args = array(
			'labels'            => $labels,
			'public'            => false,
			'show_ui'           => true,
			'show_tagcloud'     => false,
			'hierarchical'      => true,
			'rewrite'           => false,
			'show_admin_column' => true,
			'query_var'         => true,
		);

		$args = apply_filters( 'emd_slide_post_type_category_args', $args );

		register_taxonomy( $this->taxonomies[0], $this->post_type, $args );
	}
}
