<?php
/**
 * Staff Post Type
 *
 * Register post types and taxonomies.
 */
class Staff_Post_Type_Registrations {

	public $post_type = 'emd_staff';
	public $taxonomies = array( 'emd_staff_category' );

	public function init() {
		// Add the "staff" post type and taxonomies
		add_action( 'init', array( $this, 'register' ) );
	}

	public function register() {
		$this->register_post_type();
		$this->register_taxonomy_category();
	}

	/**
	 * Register the custom post type.
	 */
	protected function register_post_type() {
		$theme_slug = get_option( 'stylesheet' );
		if ( strpos( $theme_slug, '-child' ) !== false ) {
			$theme_slug = substr( $theme_slug, 0, strpos( $theme_slug, '-child' ) );
		}
		
		global ${ $theme_slug . "_options" }, ${ $theme_slug . "_config" };
		$theme_options = ${ $theme_slug . "_options" };
		$staff_cpt_i18n = ${ $theme_slug . "_config" }['staff-cpt-i18n'];

		$staff_slug = ! empty( $theme_options['staff-slug'] ) ? $theme_options['staff-slug'] : 'staff-item';
		
		$labels = ! empty( $staff_cpt_i18n['labels'] ) ? $staff_cpt_i18n['labels'] : array(
			'name'               => __( 'Staff Profiles', 'benchmark-cpts' ),
			'singular_name'      => __( 'Staff Profile', 'benchmark-cpts' ),
			'menu_name'          => __( 'Staff', 'benchmark-cpts' ),
			'name_admin_bar'     => __( 'Staff Profile', 'benchmark-cpts' ),
			'all_items'          => __( 'All Profiles', 'benchmark-cpts' ),
			'add_new'            => __( 'Add New Profile', 'benchmark-cpts' ),
			'add_new_item'       => __( 'Add New Staff Profile', 'benchmark-cpts' ),
			'edit_item'          => __( 'Edit Staff Profile', 'benchmark-cpts' ),
			'new_item'           => __( 'New Staff Profile', 'benchmark-cpts' ),
			'view_item'          => __( 'View Profile', 'benchmark-cpts' ),
			'search_items'       => __( 'Search Profiles', 'benchmark-cpts' ),
			'not_found'          => __( 'No staff profiles found', 'benchmark-cpts' ),
			'not_found_in_trash' => __( 'No staff profiles found in trash', 'benchmark-cpts' ),
		);

		$supports = array(
			'title',
			'editor',
			'excerpt',
			'thumbnail',
			//'revisions',
			'page-attributes',
		);

		$args = array(
			'labels'            => $labels,
			'supports'          => $supports,
			'public'            => true,
			'show_in_nav_menus' => true,
			'capability_type'   => 'post',
			'rewrite'           => array( 'slug' => $staff_slug ), // Permalinks format
			'menu_position'     => 115,
			'menu_icon'         => 'dashicons-id-alt',
			'has_archive'       => false,
		);

		$args = apply_filters( 'emd_staff_post_type_args', $args );

		register_post_type( $this->post_type, $args );
	}

	/**
	 * Register a taxonomy for Staff Categories.
	 */
	protected function register_taxonomy_category() {
		$theme_slug = get_option( 'stylesheet' );
		if ( strpos( $theme_slug, '-child' ) !== false ) {
			$theme_slug = substr( $theme_slug, 0, strpos( $theme_slug, '-child' ) );
		}
		
		global ${ $theme_slug . "_options" }, ${ $theme_slug . "_config" };
		$theme_options = ${ $theme_slug . "_options" };
		$staff_cpt_i18n = ${ $theme_slug . "_config" }['staff-cpt-i18n'];
		
		$staff_category_slug = ! empty( $theme_options['staff-category-slug'] ) ? $theme_options['staff-category-slug'] : 'staff-category';
		
		$labels = ! empty( $staff_cpt_i18n['cat-labels'] ) ? $staff_cpt_i18n['cat-labels'] : array(
			'name'          => __( 'Staff Categories', 'benchmark-cpts' ),
			'singular_name' => __( 'Staff Category', 'benchmark-cpts' ),
			'menu_name'     => __( 'Categories', 'benchmark-cpts' ),
			'all_items'     => __( 'All Categories', 'benchmark-cpts' ),
			'edit_item'     => __( 'Edit Staff Category', 'benchmark-cpts' ),
			'view_item'     => __( 'View Staff Category', 'benchmark-cpts' ),
			'update_item'   => __( 'Update Staff Category', 'benchmark-cpts' ),
			'add_new_item'  => __( 'Add New Category', 'benchmark-cpts' ),
			'new_item_name' => __( 'New Category Name', 'benchmark-cpts' ),
			'parent_item'   => __( 'Parent Staff Category', 'benchmark-cpts' ),
			'search_items'  => __( 'Search Categories', 'benchmark-cpts' ),
		);

		$args = array(
			'labels'            => $labels,
			'public'            => true,
			'show_in_nav_menus' => true,
			'show_tagcloud'     => true,
			'hierarchical'      => true,
			'rewrite'           => array( 'slug' => $staff_category_slug ),
			'show_admin_column' => true,
			'query_var'         => true,
		);

		$args = apply_filters( 'emd_staff_post_type_category_args', $args );

		register_taxonomy( $this->taxonomies[0], $this->post_type, $args );
	}
}
