<?php
/**
 * Testimonial Post Type
 *
 * Register post types and taxonomies.
 */
class Testimonial_Post_Type_Registrations {

	public $post_type = 'emd_testimonial';
	public $taxonomies = array( 'emd_testimonial_category' );

	public function init() {
		// Add the "testimonial" type and taxonomies
		add_action( 'init', array( $this, 'register' ) );
	}

	public function register() {
		$this->register_post_type();
		$this->register_taxonomy_category();
	}

	/**
	 * Register the custom post type.
	 */
	protected function register_post_type() {
		$theme_slug = get_option( 'stylesheet' );
		if ( strpos( $theme_slug, '-child' ) !== false ) {
			$theme_slug = substr( $theme_slug, 0, strpos( $theme_slug, '-child' ) );
		}
		
		global ${ $theme_slug . "_config" };
		$testimonial_cpt_i18n = ${ $theme_slug . "_config" }['testimonial-cpt-i18n'];

		$labels = ! empty( $testimonial_cpt_i18n['labels'] ) ? $testimonial_cpt_i18n['labels'] : array(
			'name'               => __( 'Testimonials', 'benchmark-cpts' ),
			'singular_name'      => __( 'Testimonial', 'benchmark-cpts' ),
			'menu_name'          => __( 'Testimonials', 'benchmark-cpts' ),
			'name_admin_bar'     => __( 'Testimonial', 'benchmark-cpts' ),
			'all_items'          => __( 'All Testimonials', 'benchmark-cpts' ),
			'add_new'            => __( 'Add New', 'benchmark-cpts' ),
			'add_new_item'       => __( 'Add New Testimonial', 'benchmark-cpts' ),
			'edit_item'          => __( 'Edit Testimonial', 'benchmark-cpts' ),
			'new_item'           => __( 'New Testimonial', 'benchmark-cpts' ),
			'view_item'          => __( 'View Testimonial', 'benchmark-cpts' ),
			'search_items'       => __( 'Search Testimonials', 'benchmark-cpts' ),
			'not_found'          => __( 'No testimonials found', 'benchmark-cpts' ),
			'not_found_in_trash' => __( 'No testimonials found in trash', 'benchmark-cpts' ),
		);

		$supports = array(
			'title',
			'editor',
			'thumbnail',
			'page-attributes',
		);

		$args = array(
			'labels'              => $labels,
			'supports'            => $supports,
			'public'              => false,
			'exclude_from_search' => false,
			'show_ui'             => true,
			'capability_type'     => 'post',
			'hierarchical'        => false,
			'rewrite'             => false,
			'menu_position'       => 125,
			'menu_icon'           => 'dashicons-format-quote',
			'has_archive'         => false,
			'query_var'           => false,
		);

		$args = apply_filters( 'emd_testimonial_post_type_args', $args );

		register_post_type( $this->post_type, $args );
	}

	/**
	 * Register a taxonomy for Testimonial Categories.
	 */
	protected function register_taxonomy_category() {
		$theme_slug = get_option( 'stylesheet' );
		if ( strpos( $theme_slug, '-child' ) !== false ) {
			$theme_slug = substr( $theme_slug, 0, strpos( $theme_slug, '-child' ) );
		}
		
		global ${ $theme_slug . "_config" };
		$testimonial_cpt_i18n = ${ $theme_slug . "_config" }['testimonial-cpt-i18n'];

		$labels = ! empty( $testimonial_cpt_i18n['cat-labels'] ) ? $testimonial_cpt_i18n['cat-labels'] : array(
			'name'          => __( 'Testimonial Categories', 'benchmark-cpts' ),
			'singular_name' => __( 'Testimonial Category', 'benchmark-cpts' ),
			'menu_name'     => __( 'Categories', 'benchmark-cpts' ),
			'all_items'     => __( 'All Categories', 'benchmark-cpts' ),
			'edit_item'     => __( 'Edit Testimonial Category', 'benchmark-cpts' ),
			'view_item'     => __( 'View Testimonial Category', 'benchmark-cpts' ),
			'update_item'   => __( 'Update Testimonial Category', 'benchmark-cpts' ),
			'add_new_item'  => __( 'Add New Category', 'benchmark-cpts' ),
			'new_item_name' => __( 'New Category Name', 'benchmark-cpts' ),
			'parent_item'   => __( 'Parent Category', 'benchmark-cpts' ),
			'search_items'  => __( 'Search Categories', 'benchmark-cpts' ),
		);

		$args = array(
			'labels'            => $labels,
			'public'            => false,
			'show_ui'           => true,
			'show_tagcloud'     => false,
			'hierarchical'      => true,
			'rewrite'           => false,
			'show_admin_column' => true,
			'query_var'         => true,
		);

		$args = apply_filters( 'emd_testimonial_post_type_category_args', $args );

		register_taxonomy( $this->taxonomies[0], $this->post_type, $args );
	}
}
