<?php
/**
 * Work Post Type
 *
 * Register post types and taxonomies.
 */
class Work_Post_Type_Registrations {

	public $post_type = 'emd_work';
	public $taxonomies = array( 'emd_work_category' );

	public function init() {
		// Add the "work" post type and taxonomies
		add_action( 'init', array( $this, 'register' ) );
	}

	public function register() {
		$this->register_post_type();
		$this->register_taxonomy_category();
	}

	/**
	 * Register the custom post type.
	 */
	protected function register_post_type() {
		$theme_slug = get_option( 'stylesheet' );
		if ( strpos( $theme_slug, '-child' ) !== false ) {
			$theme_slug = substr( $theme_slug, 0, strpos( $theme_slug, '-child' ) );
		}
		
		global ${ $theme_slug . "_options" }, ${ $theme_slug . "_config" };
		$theme_options = ${ $theme_slug . "_options" };
		$work_cpt_i18n = ${ $theme_slug . "_config" }['work-cpt-i18n'];
		
		$work_slug = ! empty( $theme_options['work-slug'] ) ? $theme_options['work-slug'] : 'work';
		
		$labels = ! empty( $work_cpt_i18n['labels'] ) ? $work_cpt_i18n['labels'] : array(
			'name'               => __( 'Works', 'benchmark-cpts' ),
			'singular_name'      => __( 'Work', 'benchmark-cpts' ),
			'menu_name'          => __( 'Works', 'benchmark-cpts' ),
			'name_admin_bar'     => __( 'Work', 'benchmark-cpts' ),
			'all_items'          => __( 'All Items', 'benchmark-cpts' ),
			'add_new'            => __( 'Add New Item', 'benchmark-cpts' ),
			'add_new_item'       => __( 'Add New Work', 'benchmark-cpts' ),
			'edit_item'          => __( 'Edit Work', 'benchmark-cpts' ),
			'new_item'           => __( 'New Work', 'benchmark-cpts' ),
			'view_item'          => __( 'View Item', 'benchmark-cpts' ),
			'search_items'       => __( 'Search Items', 'benchmark-cpts' ),
			'not_found'          => __( 'No works found', 'benchmark-cpts' ),
			'not_found_in_trash' => __( 'No works found in trash', 'benchmark-cpts' ),
		);

		$supports = array(
			'title',
			'editor',
			'excerpt',
			'thumbnail',
			//'revisions',
			'page-attributes',
		);

		$args = array(
			'labels'            => $labels,
			'supports'          => $supports,
			'public'            => true,
			'show_in_nav_menus' => true,
			'capability_type'   => 'post',
			'rewrite'           => array( 'slug' => $work_slug ), // Permalinks format
			'menu_position'     => 120,
			'menu_icon'         => 'dashicons-portfolio',
			'has_archive'       => false,
		);

		$args = apply_filters( 'emd_work_post_type_args', $args );

		register_post_type( $this->post_type, $args );
	}

	/**
	 * Register a taxonomy for Work Categories.
	 */
	protected function register_taxonomy_category() {
		$theme_slug = get_option( 'stylesheet' );
		if ( strpos( $theme_slug, '-child' ) !== false ) {
			$theme_slug = substr( $theme_slug, 0, strpos( $theme_slug, '-child' ) );
		}
		
		global ${ $theme_slug . "_options" }, ${ $theme_slug . "_config" };
		$theme_options = ${ $theme_slug . "_options" };
		$work_cpt_i18n = ${ $theme_slug . "_config" }['work-cpt-i18n'];
		
		$work_category_slug = ! empty( $theme_options['work-category-slug'] ) ? $theme_options['work-category-slug'] : 'work-category';
		
		$labels = ! empty( $work_cpt_i18n['cat-labels'] ) ? $work_cpt_i18n['cat-labels'] : array(
			'name'          => __( 'Work Categories', 'benchmark-cpts' ),
			'singular_name' => __( 'Work Category', 'benchmark-cpts' ),
			'menu_name'     => __( 'Categories', 'benchmark-cpts' ),
			'all_items'     => __( 'All Categories', 'benchmark-cpts' ),
			'edit_item'     => __( 'Edit Work Category', 'benchmark-cpts' ),
			'view_item'     => __( 'View Work Category', 'benchmark-cpts' ),
			'update_item'   => __( 'Update Work Category', 'benchmark-cpts' ),
			'add_new_item'  => __( 'Add New Category', 'benchmark-cpts' ),
			'new_item_name' => __( 'New Category Name', 'benchmark-cpts' ),
			'parent_item'   => __( 'Parent Work Category', 'benchmark-cpts' ),
			'search_items'  => __( 'Search Categories', 'benchmark-cpts' ),
		);

		$args = array(
			'labels'            => $labels,
			'public'            => true,
			'show_in_nav_menus' => true,
			'show_tagcloud'     => true,
			'hierarchical'      => true,
			'rewrite'           => array( 'slug' => $work_category_slug ),
			'show_admin_column' => true,
			'query_var'         => true,
		);

		$args = apply_filters( 'emd_work_post_type_category_args', $args );

		register_taxonomy( $this->taxonomies[0], $this->post_type, $args );
	}
}
